# 快应用上传脚本

欢迎使用压缩目录并上传到ES应用服务器脚本！
请确保已安装Python和zipfile库。
请输入参数：
参数说明：
--dir: 要压缩的目录路径
--zipfile: 输出的ZIP文件路径
--package_name: 包名称
--version: 版本号
--is_production: 是否为生产环境，默认为False
--refresh: 刷新标志，默认为0
--remark: 备注，默认为空
设置测试和正式环境变量 ESAPP_TEST_TOKEN  ESAPP_PROP_TOKEN

[快应用开发者网站](https://www.extscreen.com)
